@@ -131,7 +131,7 @@ public class HipsImage extends Image {
                 throw new IOException("Unable to access remote MOC properties file"+e,e);                
             }
             try {
-                mocFile = cache.getFile(mocFile, "Moc.fits");                
+                mocFile = cache.getFile(mocFile, "Moc.fits");
             } catch (Exception e) {
                 // MOC is optional
                 mocFile = null;
@@ -152,10 +152,10 @@ public class HipsImage extends Image {
         String line;
         properties = new HashMap<String,String>();
         while ( (line = propRdr.readLine()) != null) {
+            
             line = line.trim();
-            if (line.startsWith("#")) {
-                continue;
-                
+            if (line.startsWith("#")  || line.length() == 0) {
+                continue;                
             }
             String[] fields = line.split("=", 2);
             if (fields.length != 2) {
@@ -171,10 +171,19 @@ public class HipsImage extends Image {
         setOrder(scale);
 	Projection       proj = new Projection("Hpx");
         CoordinateSystem cs;
-        if (properties.get("coordsys").equals("C")) {
+        
+        boolean icrs;
+        String csStr = properties.get("coordsys");
+        if (csStr != null) {
+            icrs = csStr.toLowerCase().equals("c");
+        } else {
+            csStr = properties.get("hips_frame");
+            icrs = csStr.toLowerCase().equals("equatorial");
+        } 
+        if (icrs) {
             cs = CoordinateSystem.ICRS;
         } else {        
-	    cs   = CoordinateSystem.Gal;
+	    cs = CoordinateSystem.Gal;
         }
 	    
 	// The 0,0 point of the oblique projection is at (+2,+2) squares.
