@@ -223,15 +223,12 @@ public class XMLSurveyFinder implements SurveyFinder {
 	// that might change.  Then replace the manifest filename
 	// with the hash file name and append to base URL.
 	String filename=manifestName().replace(defaultSurveyManifest,defaultSurveyHash);
-        System.out.println("Looking at remote:"+defaultSurveyManifest+" "+defaultSurveyHash+" "+filename);
 	try {
 	    //  Constructor URL(context,spec) MUST have trailing slash
 	    //  in XMLURLPREFIX.  Make sure here.
 	    String xmlurlprefix=Settings.get("XMLURLPREFIX");
-            System.out.println("prefix is:"+xmlurlprefix);
 	    if (!xmlurlprefix.endsWith("/")) {  xmlurlprefix+="/";}
 	    String url=new URL( new URL(xmlurlprefix), filename).toString();  
-            System.out.println("Returning finally:"+url);
 	    return url;
 	} catch (Exception e) {
 	    System.err.println("ERROR trying to construct remoteCacheName from XMLURLPREFIX="+Settings.get("XMLURLPREFIX")+" and filename="+filename+":  "+e);
