@@ -222,7 +222,8 @@ public class NewTester {
             "UVOT V Counts", "UVOT B Counts", "UVOT U Counts", "UVOT UVW1 Counts",
             "UVOT UVM2 Counts", "UVOT UVW2 Counts",
             "UVOT V Exposure", "UVOT B Exposure", "UVOT U Exposure", "UVOT UVW1 Exposure",
-            "UVOT UVM2 Exposure", "UVOT UVW2 Exposure"
+            "UVOT UVM2 Exposure", "UVOT UVW2 Exposure",
+            "GLEAM 72-103", "GLEAM 103-134", "GLEAM 139-170", "GLEAM 170-231"
         };
 
         // Mellinger survey is done twice so that
